# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/canon.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2
from machinetalk.protobuf import types_pb2 as machinetalk_dot_protobuf_dot_types__pb2
from machinetalk.protobuf import emcclass_pb2 as machinetalk_dot_protobuf_dot_emcclass__pb2
from machinetalk.protobuf import motcmds_pb2 as machinetalk_dot_protobuf_dot_motcmds__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/canon.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n machinetalk/protobuf/canon.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\x1a machinetalk/protobuf/types.proto\x1a#machinetalk/protobuf/emcclass.proto\x1a\"machinetalk/protobuf/motcmds.proto\"l\n\x10\x45mc_Traj_Set_G5x\x12$\n\x06origin\x18\n \x02(\x0b\x32\x14.machinetalk.EmcPose\x12+\n\tg5x_index\x18\x14 \x02(\x0e\x32\x18.machinetalk.OriginIndex:\x05\x92?\x02Hd\"?\n\x10\x45mc_Traj_Set_G92\x12$\n\x06origin\x18\n \x02(\x0b\x32\x14.machinetalk.EmcPose:\x05\x92?\x02He\"0\n\x15\x45mc_Traj_Set_Rotation\x12\x10\n\x08rotation\x18\n \x02(\x01:\x05\x92?\x02Hf\"\xbd\x01\n\x14\x45mc_Traj_Linear_Move\x12%\n\x04type\x18\n \x02(\x0e\x32\x17.machinetalk.MotionType\x12!\n\x03\x65nd\x18\x14 \x02(\x0b\x32\x14.machinetalk.EmcPose\x12\x0b\n\x03vel\x18\x1e \x02(\x01\x12\x12\n\nini_maxvel\x18( \x02(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x32 \x02(\x01\x12\x11\n\tfeed_mode\x18< \x02(\x08\x12\x13\n\x0bindexrotary\x18\x46 \x02(\x05:\x05\x92?\x02Hg\"\xa3\x01\n\x0e\x45mc_Traj_Probe\x12%\n\x04type\x18\n \x02(\x0e\x32\x17.machinetalk.MotionType\x12!\n\x03pos\x18\x14 \x02(\x0b\x32\x14.machinetalk.EmcPose\x12\x0b\n\x03vel\x18\x1e \x02(\x01\x12\x12\n\nini_maxvel\x18( \x02(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x32 \x02(\x01\x12\x12\n\nprobe_type\x18< \x02(\r:\x05\x92?\x02Hh\"\x8c\x02\n\x16\x45mc_Traj_Circular_Move\x12%\n\x04type\x18\n \x02(\x0e\x32\x17.machinetalk.MotionType\x12!\n\x03\x65nd\x18\x14 \x02(\x0b\x32\x14.machinetalk.EmcPose\x12(\n\x06\x63\x65nter\x18\x19 \x02(\x0b\x32\x18.machinetalk.PmCartesian\x12(\n\x06normal\x18\x1b \x02(\x0b\x32\x18.machinetalk.PmCartesian\x12\x0b\n\x03vel\x18\x1e \x02(\x01\x12\x12\n\nini_maxvel\x18( \x02(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x32 \x02(\x01\x12\x11\n\tfeed_mode\x18< \x02(\x08\x12\x0c\n\x04turn\x18\x46 \x02(\x05:\x05\x92?\x02Hi\"l\n\x12\x45mc_Traj_Rigid_Tap\x12!\n\x03pos\x18\x14 \x02(\x0b\x32\x14.machinetalk.EmcPose\x12\x0b\n\x03vel\x18\x1e \x02(\x01\x12\x12\n\nini_maxvel\x18( \x02(\x01\x12\x0b\n\x03\x61\x63\x63\x18\x32 \x02(\x01:\x05\x92?\x02Hj\"`\n\x16\x45mc_Traj_Set_Term_Cond\x12,\n\x04\x63ond\x18\n \x02(\x0e\x32\x1e.machinetalk.TermConditionType\x12\x11\n\ttolerance\x18\x14 \x02(\x01:\x05\x92?\x02Hk\"U\n\x18\x45mc_Traj_Set_Spindlesync\x12\x1b\n\x13\x66\x65\x65\x64_per_revolution\x18\n \x02(\x01\x12\x15\n\rvelocity_mode\x18\x14 \x02(\x08:\x05\x92?\x02Hl\"&\n\x0e\x45mc_Traj_Delay\x12\r\n\x05\x64\x65lay\x18\n \x02(\x01:\x05\x92?\x02Hm\"P\n\x0e\x45mc_Spindle_On\x12\x10\n\x05speed\x18\n \x02(\x01:\x01\x30\x12\x11\n\x06\x66\x61\x63tor\x18\x14 \x02(\x01:\x01\x30\x12\x12\n\x07xoffset\x18\x1e \x02(\x01:\x01\x30:\x05\x92?\x02Hn\"J\n\x11\x45mc_Spindle_Speed\x12\r\n\x05speed\x18\n \x02(\x01\x12\x0e\n\x06\x66\x61\x63tor\x18\x14 \x02(\x01\x12\x0f\n\x07xoffset\x18\x1e \x02(\x01:\x05\x92?\x02Ho\"[\n\x12\x45mc_Spindle_Orient\x12\x13\n\x0borientation\x18\n \x02(\x01\x12)\n\x04mode\x18\x14 \x02(\x0e\x32\x1b.machinetalk.CanonDirection:\x05\x92?\x02Hp\":\n Emc_Spindle_Wait_Orient_Complete\x12\x0f\n\x07timeout\x18\n \x02(\x01:\x05\x92?\x02Hq\"\xb0\x01\n\x13\x45mc_Tool_Set_Offset\x12\x0e\n\x06pocket\x18\n \x02(\x05\x12\x0e\n\x06toolno\x18\x0f \x02(\x05\x12$\n\x06offset\x18\x14 \x02(\x0b\x32\x14.machinetalk.EmcPose\x12\x10\n\x08\x64iameter\x18\x1e \x02(\x01\x12\x12\n\nfrontangle\x18( \x02(\x01\x12\x11\n\tbackangle\x18\x32 \x02(\x01\x12\x13\n\x0borientation\x18< \x02(\x05:\x05\x92?\x02Hr\"B\n\x13\x45mc_Traj_Set_Offset\x12$\n\x06offset\x18\n \x02(\x0b\x32\x14.machinetalk.EmcPose:\x05\x92?\x02Hs\"7\n\x10\x45mc_Tool_Prepare\x12\x0e\n\x06pocket\x18\n \x02(\x05\x12\x0c\n\x04tool\x18\x14 \x02(\x05:\x05\x92?\x02Ht\"*\n\x13\x45mc_Tool_Set_Number\x12\x0c\n\x04tool\x18\n \x02(\x05:\x05\x92?\x02Hu\"-\n\x16\x45mc_Traj_Set_Fo_Enable\x12\x0c\n\x04mode\x18\n \x02(\x08:\x05\x92?\x02Hv\"-\n\x16\x45mc_Traj_Set_So_Enable\x12\x0c\n\x04mode\x18\n \x02(\x08:\x05\x92?\x02Hw\"-\n\x16\x45mc_Traj_Set_Fh_Enable\x12\x0c\n\x04mode\x18\n \x02(\x08:\x05\x92?\x02Hx\",\n\x13\x45mc_Motion_Adaptive\x12\x0e\n\x06status\x18\n \x02(\x08:\x05\x92?\x02Hy\":\n\x14\x45mc_Operator_Display\x12\n\n\x02id\x18\n \x02(\x05\x12\x0f\n\x07\x64isplay\x18\x14 \x02(\t:\x05\x92?\x02Hz\"4\n\x11\x45mc_Operator_Text\x12\n\n\x02id\x18\n \x02(\x05\x12\x0c\n\x04text\x18\x14 \x02(\t:\x05\x92?\x02H{\"6\n\x12\x45mc_Operator_Error\x12\n\n\x02id\x18\n \x02(\x05\x12\r\n\x05\x65rror\x18\x14 \x02(\t:\x05\x92?\x02H|\"T\n\x13\x45mc_Motion_Set_Dout\x12\r\n\x05index\x18\n \x02(\r\x12\r\n\x05start\x18\x14 \x02(\x08\x12\x0b\n\x03\x65nd\x18\x1e \x02(\x08\x12\x0b\n\x03now\x18( \x02(\x08:\x05\x92?\x02H}\"T\n\x13\x45mc_Motion_Set_Aout\x12\r\n\x05index\x18\n \x02(\r\x12\r\n\x05start\x18\x14 \x02(\x01\x12\x0b\n\x03\x65nd\x18\x1e \x02(\x01\x12\x0b\n\x03now\x18( \x02(\x08:\x05\x92?\x02H~\"\x91\x01\n\x12\x45mc_Aux_Input_Wait\x12\r\n\x05index\x18\n \x02(\r\x12*\n\ninput_type\x18\x14 \x02(\x0e\x32\x16.machinetalk.InputType\x12(\n\twait_type\x18\x1e \x02(\x0e\x32\x15.machinetalk.WaitType\x12\x0f\n\x07timeout\x18( \x02(\x01:\x05\x92?\x02H\x7f\",\n\x14\x45mc_Exec_Plugin_Ca1l\x12\x0c\n\x04\x63\x61ll\x18\x14 \x02(\x0c:\x06\x92?\x03H\x80\x01\"*\n\x12\x45mc_Io_Plugin_Call\x12\x0c\n\x04\x63\x61ll\x18\x14 \x02(\x0c:\x06\x92?\x03H\x81\x01')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_types__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_emcclass__pb2.DESCRIPTOR,machinetalk_dot_protobuf_dot_motcmds__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_EMC_TRAJ_SET_G5X = _descriptor.Descriptor(
  name='Emc_Traj_Set_G5x',
  full_name='machinetalk.Emc_Traj_Set_G5x',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.Emc_Traj_Set_G5x.origin', index=0,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='g5x_index', full_name='machinetalk.Emc_Traj_Set_G5x.g5x_index', index=1,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hd')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=191,
  serialized_end=299,
)


_EMC_TRAJ_SET_G92 = _descriptor.Descriptor(
  name='Emc_Traj_Set_G92',
  full_name='machinetalk.Emc_Traj_Set_G92',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='origin', full_name='machinetalk.Emc_Traj_Set_G92.origin', index=0,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002He')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=301,
  serialized_end=364,
)


_EMC_TRAJ_SET_ROTATION = _descriptor.Descriptor(
  name='Emc_Traj_Set_Rotation',
  full_name='machinetalk.Emc_Traj_Set_Rotation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rotation', full_name='machinetalk.Emc_Traj_Set_Rotation.rotation', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hf')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=366,
  serialized_end=414,
)


_EMC_TRAJ_LINEAR_MOVE = _descriptor.Descriptor(
  name='Emc_Traj_Linear_Move',
  full_name='machinetalk.Emc_Traj_Linear_Move',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Emc_Traj_Linear_Move.type', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='machinetalk.Emc_Traj_Linear_Move.end', index=1,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vel', full_name='machinetalk.Emc_Traj_Linear_Move.vel', index=2,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ini_maxvel', full_name='machinetalk.Emc_Traj_Linear_Move.ini_maxvel', index=3,
      number=40, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acc', full_name='machinetalk.Emc_Traj_Linear_Move.acc', index=4,
      number=50, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feed_mode', full_name='machinetalk.Emc_Traj_Linear_Move.feed_mode', index=5,
      number=60, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='indexrotary', full_name='machinetalk.Emc_Traj_Linear_Move.indexrotary', index=6,
      number=70, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hg')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=606,
)


_EMC_TRAJ_PROBE = _descriptor.Descriptor(
  name='Emc_Traj_Probe',
  full_name='machinetalk.Emc_Traj_Probe',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Emc_Traj_Probe.type', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pos', full_name='machinetalk.Emc_Traj_Probe.pos', index=1,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vel', full_name='machinetalk.Emc_Traj_Probe.vel', index=2,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ini_maxvel', full_name='machinetalk.Emc_Traj_Probe.ini_maxvel', index=3,
      number=40, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acc', full_name='machinetalk.Emc_Traj_Probe.acc', index=4,
      number=50, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='probe_type', full_name='machinetalk.Emc_Traj_Probe.probe_type', index=5,
      number=60, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hh')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=609,
  serialized_end=772,
)


_EMC_TRAJ_CIRCULAR_MOVE = _descriptor.Descriptor(
  name='Emc_Traj_Circular_Move',
  full_name='machinetalk.Emc_Traj_Circular_Move',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='machinetalk.Emc_Traj_Circular_Move.type', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='machinetalk.Emc_Traj_Circular_Move.end', index=1,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='center', full_name='machinetalk.Emc_Traj_Circular_Move.center', index=2,
      number=25, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='normal', full_name='machinetalk.Emc_Traj_Circular_Move.normal', index=3,
      number=27, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vel', full_name='machinetalk.Emc_Traj_Circular_Move.vel', index=4,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ini_maxvel', full_name='machinetalk.Emc_Traj_Circular_Move.ini_maxvel', index=5,
      number=40, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acc', full_name='machinetalk.Emc_Traj_Circular_Move.acc', index=6,
      number=50, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='feed_mode', full_name='machinetalk.Emc_Traj_Circular_Move.feed_mode', index=7,
      number=60, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='turn', full_name='machinetalk.Emc_Traj_Circular_Move.turn', index=8,
      number=70, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hi')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=775,
  serialized_end=1043,
)


_EMC_TRAJ_RIGID_TAP = _descriptor.Descriptor(
  name='Emc_Traj_Rigid_Tap',
  full_name='machinetalk.Emc_Traj_Rigid_Tap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pos', full_name='machinetalk.Emc_Traj_Rigid_Tap.pos', index=0,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='vel', full_name='machinetalk.Emc_Traj_Rigid_Tap.vel', index=1,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ini_maxvel', full_name='machinetalk.Emc_Traj_Rigid_Tap.ini_maxvel', index=2,
      number=40, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='acc', full_name='machinetalk.Emc_Traj_Rigid_Tap.acc', index=3,
      number=50, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hj')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1045,
  serialized_end=1153,
)


_EMC_TRAJ_SET_TERM_COND = _descriptor.Descriptor(
  name='Emc_Traj_Set_Term_Cond',
  full_name='machinetalk.Emc_Traj_Set_Term_Cond',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='cond', full_name='machinetalk.Emc_Traj_Set_Term_Cond.cond', index=0,
      number=10, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tolerance', full_name='machinetalk.Emc_Traj_Set_Term_Cond.tolerance', index=1,
      number=20, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hk')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1155,
  serialized_end=1251,
)


_EMC_TRAJ_SET_SPINDLESYNC = _descriptor.Descriptor(
  name='Emc_Traj_Set_Spindlesync',
  full_name='machinetalk.Emc_Traj_Set_Spindlesync',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_per_revolution', full_name='machinetalk.Emc_Traj_Set_Spindlesync.feed_per_revolution', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='velocity_mode', full_name='machinetalk.Emc_Traj_Set_Spindlesync.velocity_mode', index=1,
      number=20, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hl')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1253,
  serialized_end=1338,
)


_EMC_TRAJ_DELAY = _descriptor.Descriptor(
  name='Emc_Traj_Delay',
  full_name='machinetalk.Emc_Traj_Delay',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='delay', full_name='machinetalk.Emc_Traj_Delay.delay', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hm')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1340,
  serialized_end=1378,
)


_EMC_SPINDLE_ON = _descriptor.Descriptor(
  name='Emc_Spindle_On',
  full_name='machinetalk.Emc_Spindle_On',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='machinetalk.Emc_Spindle_On.speed', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='factor', full_name='machinetalk.Emc_Spindle_On.factor', index=1,
      number=20, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xoffset', full_name='machinetalk.Emc_Spindle_On.xoffset', index=2,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hn')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1380,
  serialized_end=1460,
)


_EMC_SPINDLE_SPEED = _descriptor.Descriptor(
  name='Emc_Spindle_Speed',
  full_name='machinetalk.Emc_Spindle_Speed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='speed', full_name='machinetalk.Emc_Spindle_Speed.speed', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='factor', full_name='machinetalk.Emc_Spindle_Speed.factor', index=1,
      number=20, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xoffset', full_name='machinetalk.Emc_Spindle_Speed.xoffset', index=2,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Ho')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1462,
  serialized_end=1536,
)


_EMC_SPINDLE_ORIENT = _descriptor.Descriptor(
  name='Emc_Spindle_Orient',
  full_name='machinetalk.Emc_Spindle_Orient',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='orientation', full_name='machinetalk.Emc_Spindle_Orient.orientation', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mode', full_name='machinetalk.Emc_Spindle_Orient.mode', index=1,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hp')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1538,
  serialized_end=1629,
)


_EMC_SPINDLE_WAIT_ORIENT_COMPLETE = _descriptor.Descriptor(
  name='Emc_Spindle_Wait_Orient_Complete',
  full_name='machinetalk.Emc_Spindle_Wait_Orient_Complete',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='machinetalk.Emc_Spindle_Wait_Orient_Complete.timeout', index=0,
      number=10, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hq')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1631,
  serialized_end=1689,
)


_EMC_TOOL_SET_OFFSET = _descriptor.Descriptor(
  name='Emc_Tool_Set_Offset',
  full_name='machinetalk.Emc_Tool_Set_Offset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pocket', full_name='machinetalk.Emc_Tool_Set_Offset.pocket', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='toolno', full_name='machinetalk.Emc_Tool_Set_Offset.toolno', index=1,
      number=15, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='machinetalk.Emc_Tool_Set_Offset.offset', index=2,
      number=20, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='diameter', full_name='machinetalk.Emc_Tool_Set_Offset.diameter', index=3,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='frontangle', full_name='machinetalk.Emc_Tool_Set_Offset.frontangle', index=4,
      number=40, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='backangle', full_name='machinetalk.Emc_Tool_Set_Offset.backangle', index=5,
      number=50, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='orientation', full_name='machinetalk.Emc_Tool_Set_Offset.orientation', index=6,
      number=60, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hr')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1692,
  serialized_end=1868,
)


_EMC_TRAJ_SET_OFFSET = _descriptor.Descriptor(
  name='Emc_Traj_Set_Offset',
  full_name='machinetalk.Emc_Traj_Set_Offset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='machinetalk.Emc_Traj_Set_Offset.offset', index=0,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hs')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1936,
)


_EMC_TOOL_PREPARE = _descriptor.Descriptor(
  name='Emc_Tool_Prepare',
  full_name='machinetalk.Emc_Tool_Prepare',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pocket', full_name='machinetalk.Emc_Tool_Prepare.pocket', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tool', full_name='machinetalk.Emc_Tool_Prepare.tool', index=1,
      number=20, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Ht')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1938,
  serialized_end=1993,
)


_EMC_TOOL_SET_NUMBER = _descriptor.Descriptor(
  name='Emc_Tool_Set_Number',
  full_name='machinetalk.Emc_Tool_Set_Number',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tool', full_name='machinetalk.Emc_Tool_Set_Number.tool', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hu')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1995,
  serialized_end=2037,
)


_EMC_TRAJ_SET_FO_ENABLE = _descriptor.Descriptor(
  name='Emc_Traj_Set_Fo_Enable',
  full_name='machinetalk.Emc_Traj_Set_Fo_Enable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='machinetalk.Emc_Traj_Set_Fo_Enable.mode', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hv')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2084,
)


_EMC_TRAJ_SET_SO_ENABLE = _descriptor.Descriptor(
  name='Emc_Traj_Set_So_Enable',
  full_name='machinetalk.Emc_Traj_Set_So_Enable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='machinetalk.Emc_Traj_Set_So_Enable.mode', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hw')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2086,
  serialized_end=2131,
)


_EMC_TRAJ_SET_FH_ENABLE = _descriptor.Descriptor(
  name='Emc_Traj_Set_Fh_Enable',
  full_name='machinetalk.Emc_Traj_Set_Fh_Enable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='machinetalk.Emc_Traj_Set_Fh_Enable.mode', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hx')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2133,
  serialized_end=2178,
)


_EMC_MOTION_ADAPTIVE = _descriptor.Descriptor(
  name='Emc_Motion_Adaptive',
  full_name='machinetalk.Emc_Motion_Adaptive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='machinetalk.Emc_Motion_Adaptive.status', index=0,
      number=10, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hy')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2180,
  serialized_end=2224,
)


_EMC_OPERATOR_DISPLAY = _descriptor.Descriptor(
  name='Emc_Operator_Display',
  full_name='machinetalk.Emc_Operator_Display',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Emc_Operator_Display.id', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='display', full_name='machinetalk.Emc_Operator_Display.display', index=1,
      number=20, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hz')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2226,
  serialized_end=2284,
)


_EMC_OPERATOR_TEXT = _descriptor.Descriptor(
  name='Emc_Operator_Text',
  full_name='machinetalk.Emc_Operator_Text',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Emc_Operator_Text.id', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='text', full_name='machinetalk.Emc_Operator_Text.text', index=1,
      number=20, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H{')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2286,
  serialized_end=2338,
)


_EMC_OPERATOR_ERROR = _descriptor.Descriptor(
  name='Emc_Operator_Error',
  full_name='machinetalk.Emc_Operator_Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='machinetalk.Emc_Operator_Error.id', index=0,
      number=10, type=5, cpp_type=1, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error', full_name='machinetalk.Emc_Operator_Error.error', index=1,
      number=20, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H|')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2340,
  serialized_end=2394,
)


_EMC_MOTION_SET_DOUT = _descriptor.Descriptor(
  name='Emc_Motion_Set_Dout',
  full_name='machinetalk.Emc_Motion_Set_Dout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.Emc_Motion_Set_Dout.index', index=0,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start', full_name='machinetalk.Emc_Motion_Set_Dout.start', index=1,
      number=20, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='machinetalk.Emc_Motion_Set_Dout.end', index=2,
      number=30, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='now', full_name='machinetalk.Emc_Motion_Set_Dout.now', index=3,
      number=40, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H}')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2396,
  serialized_end=2480,
)


_EMC_MOTION_SET_AOUT = _descriptor.Descriptor(
  name='Emc_Motion_Set_Aout',
  full_name='machinetalk.Emc_Motion_Set_Aout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.Emc_Motion_Set_Aout.index', index=0,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='start', full_name='machinetalk.Emc_Motion_Set_Aout.start', index=1,
      number=20, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='end', full_name='machinetalk.Emc_Motion_Set_Aout.end', index=2,
      number=30, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='now', full_name='machinetalk.Emc_Motion_Set_Aout.now', index=3,
      number=40, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H~')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2482,
  serialized_end=2566,
)


_EMC_AUX_INPUT_WAIT = _descriptor.Descriptor(
  name='Emc_Aux_Input_Wait',
  full_name='machinetalk.Emc_Aux_Input_Wait',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='machinetalk.Emc_Aux_Input_Wait.index', index=0,
      number=10, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_type', full_name='machinetalk.Emc_Aux_Input_Wait.input_type', index=1,
      number=20, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='wait_type', full_name='machinetalk.Emc_Aux_Input_Wait.wait_type', index=2,
      number=30, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='machinetalk.Emc_Aux_Input_Wait.timeout', index=3,
      number=40, type=1, cpp_type=5, label=2,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H\177')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2569,
  serialized_end=2714,
)


_EMC_EXEC_PLUGIN_CA1L = _descriptor.Descriptor(
  name='Emc_Exec_Plugin_Ca1l',
  full_name='machinetalk.Emc_Exec_Plugin_Ca1l',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call', full_name='machinetalk.Emc_Exec_Plugin_Ca1l.call', index=0,
      number=20, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\200\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2716,
  serialized_end=2760,
)


_EMC_IO_PLUGIN_CALL = _descriptor.Descriptor(
  name='Emc_Io_Plugin_Call',
  full_name='machinetalk.Emc_Io_Plugin_Call',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='call', full_name='machinetalk.Emc_Io_Plugin_Call.call', index=0,
      number=20, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\201\001')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2762,
  serialized_end=2804,
)

_EMC_TRAJ_SET_G5X.fields_by_name['origin'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_SET_G5X.fields_by_name['g5x_index'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._ORIGININDEX
_EMC_TRAJ_SET_G92.fields_by_name['origin'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_LINEAR_MOVE.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_motcmds__pb2._MOTIONTYPE
_EMC_TRAJ_LINEAR_MOVE.fields_by_name['end'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_PROBE.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_motcmds__pb2._MOTIONTYPE
_EMC_TRAJ_PROBE.fields_by_name['pos'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_CIRCULAR_MOVE.fields_by_name['type'].enum_type = machinetalk_dot_protobuf_dot_motcmds__pb2._MOTIONTYPE
_EMC_TRAJ_CIRCULAR_MOVE.fields_by_name['end'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_CIRCULAR_MOVE.fields_by_name['center'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._PMCARTESIAN
_EMC_TRAJ_CIRCULAR_MOVE.fields_by_name['normal'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._PMCARTESIAN
_EMC_TRAJ_RIGID_TAP.fields_by_name['pos'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_SET_TERM_COND.fields_by_name['cond'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._TERMCONDITIONTYPE
_EMC_SPINDLE_ORIENT.fields_by_name['mode'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._CANONDIRECTION
_EMC_TOOL_SET_OFFSET.fields_by_name['offset'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_TRAJ_SET_OFFSET.fields_by_name['offset'].message_type = machinetalk_dot_protobuf_dot_emcclass__pb2._EMCPOSE
_EMC_AUX_INPUT_WAIT.fields_by_name['input_type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._INPUTTYPE
_EMC_AUX_INPUT_WAIT.fields_by_name['wait_type'].enum_type = machinetalk_dot_protobuf_dot_types__pb2._WAITTYPE
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_G5x'] = _EMC_TRAJ_SET_G5X
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_G92'] = _EMC_TRAJ_SET_G92
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_Rotation'] = _EMC_TRAJ_SET_ROTATION
DESCRIPTOR.message_types_by_name['Emc_Traj_Linear_Move'] = _EMC_TRAJ_LINEAR_MOVE
DESCRIPTOR.message_types_by_name['Emc_Traj_Probe'] = _EMC_TRAJ_PROBE
DESCRIPTOR.message_types_by_name['Emc_Traj_Circular_Move'] = _EMC_TRAJ_CIRCULAR_MOVE
DESCRIPTOR.message_types_by_name['Emc_Traj_Rigid_Tap'] = _EMC_TRAJ_RIGID_TAP
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_Term_Cond'] = _EMC_TRAJ_SET_TERM_COND
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_Spindlesync'] = _EMC_TRAJ_SET_SPINDLESYNC
DESCRIPTOR.message_types_by_name['Emc_Traj_Delay'] = _EMC_TRAJ_DELAY
DESCRIPTOR.message_types_by_name['Emc_Spindle_On'] = _EMC_SPINDLE_ON
DESCRIPTOR.message_types_by_name['Emc_Spindle_Speed'] = _EMC_SPINDLE_SPEED
DESCRIPTOR.message_types_by_name['Emc_Spindle_Orient'] = _EMC_SPINDLE_ORIENT
DESCRIPTOR.message_types_by_name['Emc_Spindle_Wait_Orient_Complete'] = _EMC_SPINDLE_WAIT_ORIENT_COMPLETE
DESCRIPTOR.message_types_by_name['Emc_Tool_Set_Offset'] = _EMC_TOOL_SET_OFFSET
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_Offset'] = _EMC_TRAJ_SET_OFFSET
DESCRIPTOR.message_types_by_name['Emc_Tool_Prepare'] = _EMC_TOOL_PREPARE
DESCRIPTOR.message_types_by_name['Emc_Tool_Set_Number'] = _EMC_TOOL_SET_NUMBER
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_Fo_Enable'] = _EMC_TRAJ_SET_FO_ENABLE
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_So_Enable'] = _EMC_TRAJ_SET_SO_ENABLE
DESCRIPTOR.message_types_by_name['Emc_Traj_Set_Fh_Enable'] = _EMC_TRAJ_SET_FH_ENABLE
DESCRIPTOR.message_types_by_name['Emc_Motion_Adaptive'] = _EMC_MOTION_ADAPTIVE
DESCRIPTOR.message_types_by_name['Emc_Operator_Display'] = _EMC_OPERATOR_DISPLAY
DESCRIPTOR.message_types_by_name['Emc_Operator_Text'] = _EMC_OPERATOR_TEXT
DESCRIPTOR.message_types_by_name['Emc_Operator_Error'] = _EMC_OPERATOR_ERROR
DESCRIPTOR.message_types_by_name['Emc_Motion_Set_Dout'] = _EMC_MOTION_SET_DOUT
DESCRIPTOR.message_types_by_name['Emc_Motion_Set_Aout'] = _EMC_MOTION_SET_AOUT
DESCRIPTOR.message_types_by_name['Emc_Aux_Input_Wait'] = _EMC_AUX_INPUT_WAIT
DESCRIPTOR.message_types_by_name['Emc_Exec_Plugin_Ca1l'] = _EMC_EXEC_PLUGIN_CA1L
DESCRIPTOR.message_types_by_name['Emc_Io_Plugin_Call'] = _EMC_IO_PLUGIN_CALL

Emc_Traj_Set_G5x = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_G5x', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_G5X,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_G5x)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_G5x)

Emc_Traj_Set_G92 = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_G92', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_G92,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_G92)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_G92)

Emc_Traj_Set_Rotation = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_Rotation', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_ROTATION,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_Rotation)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_Rotation)

Emc_Traj_Linear_Move = _reflection.GeneratedProtocolMessageType('Emc_Traj_Linear_Move', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_LINEAR_MOVE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Linear_Move)
  ))
_sym_db.RegisterMessage(Emc_Traj_Linear_Move)

Emc_Traj_Probe = _reflection.GeneratedProtocolMessageType('Emc_Traj_Probe', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_PROBE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Probe)
  ))
_sym_db.RegisterMessage(Emc_Traj_Probe)

Emc_Traj_Circular_Move = _reflection.GeneratedProtocolMessageType('Emc_Traj_Circular_Move', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_CIRCULAR_MOVE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Circular_Move)
  ))
_sym_db.RegisterMessage(Emc_Traj_Circular_Move)

Emc_Traj_Rigid_Tap = _reflection.GeneratedProtocolMessageType('Emc_Traj_Rigid_Tap', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_RIGID_TAP,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Rigid_Tap)
  ))
_sym_db.RegisterMessage(Emc_Traj_Rigid_Tap)

Emc_Traj_Set_Term_Cond = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_Term_Cond', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_TERM_COND,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_Term_Cond)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_Term_Cond)

Emc_Traj_Set_Spindlesync = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_Spindlesync', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_SPINDLESYNC,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_Spindlesync)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_Spindlesync)

Emc_Traj_Delay = _reflection.GeneratedProtocolMessageType('Emc_Traj_Delay', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_DELAY,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Delay)
  ))
_sym_db.RegisterMessage(Emc_Traj_Delay)

Emc_Spindle_On = _reflection.GeneratedProtocolMessageType('Emc_Spindle_On', (_message.Message,), dict(
  DESCRIPTOR = _EMC_SPINDLE_ON,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Spindle_On)
  ))
_sym_db.RegisterMessage(Emc_Spindle_On)

Emc_Spindle_Speed = _reflection.GeneratedProtocolMessageType('Emc_Spindle_Speed', (_message.Message,), dict(
  DESCRIPTOR = _EMC_SPINDLE_SPEED,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Spindle_Speed)
  ))
_sym_db.RegisterMessage(Emc_Spindle_Speed)

Emc_Spindle_Orient = _reflection.GeneratedProtocolMessageType('Emc_Spindle_Orient', (_message.Message,), dict(
  DESCRIPTOR = _EMC_SPINDLE_ORIENT,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Spindle_Orient)
  ))
_sym_db.RegisterMessage(Emc_Spindle_Orient)

Emc_Spindle_Wait_Orient_Complete = _reflection.GeneratedProtocolMessageType('Emc_Spindle_Wait_Orient_Complete', (_message.Message,), dict(
  DESCRIPTOR = _EMC_SPINDLE_WAIT_ORIENT_COMPLETE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Spindle_Wait_Orient_Complete)
  ))
_sym_db.RegisterMessage(Emc_Spindle_Wait_Orient_Complete)

Emc_Tool_Set_Offset = _reflection.GeneratedProtocolMessageType('Emc_Tool_Set_Offset', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TOOL_SET_OFFSET,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Tool_Set_Offset)
  ))
_sym_db.RegisterMessage(Emc_Tool_Set_Offset)

Emc_Traj_Set_Offset = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_Offset', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_OFFSET,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_Offset)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_Offset)

Emc_Tool_Prepare = _reflection.GeneratedProtocolMessageType('Emc_Tool_Prepare', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TOOL_PREPARE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Tool_Prepare)
  ))
_sym_db.RegisterMessage(Emc_Tool_Prepare)

Emc_Tool_Set_Number = _reflection.GeneratedProtocolMessageType('Emc_Tool_Set_Number', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TOOL_SET_NUMBER,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Tool_Set_Number)
  ))
_sym_db.RegisterMessage(Emc_Tool_Set_Number)

Emc_Traj_Set_Fo_Enable = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_Fo_Enable', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_FO_ENABLE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_Fo_Enable)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_Fo_Enable)

Emc_Traj_Set_So_Enable = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_So_Enable', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_SO_ENABLE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_So_Enable)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_So_Enable)

Emc_Traj_Set_Fh_Enable = _reflection.GeneratedProtocolMessageType('Emc_Traj_Set_Fh_Enable', (_message.Message,), dict(
  DESCRIPTOR = _EMC_TRAJ_SET_FH_ENABLE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Traj_Set_Fh_Enable)
  ))
_sym_db.RegisterMessage(Emc_Traj_Set_Fh_Enable)

Emc_Motion_Adaptive = _reflection.GeneratedProtocolMessageType('Emc_Motion_Adaptive', (_message.Message,), dict(
  DESCRIPTOR = _EMC_MOTION_ADAPTIVE,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Motion_Adaptive)
  ))
_sym_db.RegisterMessage(Emc_Motion_Adaptive)

Emc_Operator_Display = _reflection.GeneratedProtocolMessageType('Emc_Operator_Display', (_message.Message,), dict(
  DESCRIPTOR = _EMC_OPERATOR_DISPLAY,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Operator_Display)
  ))
_sym_db.RegisterMessage(Emc_Operator_Display)

Emc_Operator_Text = _reflection.GeneratedProtocolMessageType('Emc_Operator_Text', (_message.Message,), dict(
  DESCRIPTOR = _EMC_OPERATOR_TEXT,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Operator_Text)
  ))
_sym_db.RegisterMessage(Emc_Operator_Text)

Emc_Operator_Error = _reflection.GeneratedProtocolMessageType('Emc_Operator_Error', (_message.Message,), dict(
  DESCRIPTOR = _EMC_OPERATOR_ERROR,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Operator_Error)
  ))
_sym_db.RegisterMessage(Emc_Operator_Error)

Emc_Motion_Set_Dout = _reflection.GeneratedProtocolMessageType('Emc_Motion_Set_Dout', (_message.Message,), dict(
  DESCRIPTOR = _EMC_MOTION_SET_DOUT,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Motion_Set_Dout)
  ))
_sym_db.RegisterMessage(Emc_Motion_Set_Dout)

Emc_Motion_Set_Aout = _reflection.GeneratedProtocolMessageType('Emc_Motion_Set_Aout', (_message.Message,), dict(
  DESCRIPTOR = _EMC_MOTION_SET_AOUT,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Motion_Set_Aout)
  ))
_sym_db.RegisterMessage(Emc_Motion_Set_Aout)

Emc_Aux_Input_Wait = _reflection.GeneratedProtocolMessageType('Emc_Aux_Input_Wait', (_message.Message,), dict(
  DESCRIPTOR = _EMC_AUX_INPUT_WAIT,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Aux_Input_Wait)
  ))
_sym_db.RegisterMessage(Emc_Aux_Input_Wait)

Emc_Exec_Plugin_Ca1l = _reflection.GeneratedProtocolMessageType('Emc_Exec_Plugin_Ca1l', (_message.Message,), dict(
  DESCRIPTOR = _EMC_EXEC_PLUGIN_CA1L,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Exec_Plugin_Ca1l)
  ))
_sym_db.RegisterMessage(Emc_Exec_Plugin_Ca1l)

Emc_Io_Plugin_Call = _reflection.GeneratedProtocolMessageType('Emc_Io_Plugin_Call', (_message.Message,), dict(
  DESCRIPTOR = _EMC_IO_PLUGIN_CALL,
  __module__ = 'machinetalk.protobuf.canon_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.Emc_Io_Plugin_Call)
  ))
_sym_db.RegisterMessage(Emc_Io_Plugin_Call)


_EMC_TRAJ_SET_G5X.has_options = True
_EMC_TRAJ_SET_G5X._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hd'))
_EMC_TRAJ_SET_G92.has_options = True
_EMC_TRAJ_SET_G92._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002He'))
_EMC_TRAJ_SET_ROTATION.has_options = True
_EMC_TRAJ_SET_ROTATION._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hf'))
_EMC_TRAJ_LINEAR_MOVE.has_options = True
_EMC_TRAJ_LINEAR_MOVE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hg'))
_EMC_TRAJ_PROBE.has_options = True
_EMC_TRAJ_PROBE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hh'))
_EMC_TRAJ_CIRCULAR_MOVE.has_options = True
_EMC_TRAJ_CIRCULAR_MOVE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hi'))
_EMC_TRAJ_RIGID_TAP.has_options = True
_EMC_TRAJ_RIGID_TAP._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hj'))
_EMC_TRAJ_SET_TERM_COND.has_options = True
_EMC_TRAJ_SET_TERM_COND._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hk'))
_EMC_TRAJ_SET_SPINDLESYNC.has_options = True
_EMC_TRAJ_SET_SPINDLESYNC._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hl'))
_EMC_TRAJ_DELAY.has_options = True
_EMC_TRAJ_DELAY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hm'))
_EMC_SPINDLE_ON.has_options = True
_EMC_SPINDLE_ON._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hn'))
_EMC_SPINDLE_SPEED.has_options = True
_EMC_SPINDLE_SPEED._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Ho'))
_EMC_SPINDLE_ORIENT.has_options = True
_EMC_SPINDLE_ORIENT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hp'))
_EMC_SPINDLE_WAIT_ORIENT_COMPLETE.has_options = True
_EMC_SPINDLE_WAIT_ORIENT_COMPLETE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hq'))
_EMC_TOOL_SET_OFFSET.has_options = True
_EMC_TOOL_SET_OFFSET._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hr'))
_EMC_TRAJ_SET_OFFSET.has_options = True
_EMC_TRAJ_SET_OFFSET._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hs'))
_EMC_TOOL_PREPARE.has_options = True
_EMC_TOOL_PREPARE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Ht'))
_EMC_TOOL_SET_NUMBER.has_options = True
_EMC_TOOL_SET_NUMBER._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hu'))
_EMC_TRAJ_SET_FO_ENABLE.has_options = True
_EMC_TRAJ_SET_FO_ENABLE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hv'))
_EMC_TRAJ_SET_SO_ENABLE.has_options = True
_EMC_TRAJ_SET_SO_ENABLE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hw'))
_EMC_TRAJ_SET_FH_ENABLE.has_options = True
_EMC_TRAJ_SET_FH_ENABLE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hx'))
_EMC_MOTION_ADAPTIVE.has_options = True
_EMC_MOTION_ADAPTIVE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hy'))
_EMC_OPERATOR_DISPLAY.has_options = True
_EMC_OPERATOR_DISPLAY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002Hz'))
_EMC_OPERATOR_TEXT.has_options = True
_EMC_OPERATOR_TEXT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H{'))
_EMC_OPERATOR_ERROR.has_options = True
_EMC_OPERATOR_ERROR._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H|'))
_EMC_MOTION_SET_DOUT.has_options = True
_EMC_MOTION_SET_DOUT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H}'))
_EMC_MOTION_SET_AOUT.has_options = True
_EMC_MOTION_SET_AOUT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H~'))
_EMC_AUX_INPUT_WAIT.has_options = True
_EMC_AUX_INPUT_WAIT._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\002H\177'))
_EMC_EXEC_PLUGIN_CA1L.has_options = True
_EMC_EXEC_PLUGIN_CA1L._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\200\001'))
_EMC_IO_PLUGIN_CALL.has_options = True
_EMC_IO_PLUGIN_CALL._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\201\001'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: machinetalk/protobuf/emcclass.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from machinetalk.protobuf import nanopb_pb2 as machinetalk_dot_protobuf_dot_nanopb__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='machinetalk/protobuf/emcclass.proto',
  package='machinetalk',
  syntax='proto2',
  serialized_pb=_b('\n#machinetalk/protobuf/emcclass.proto\x12\x0bmachinetalk\x1a!machinetalk/protobuf/nanopb.proto\"6\n\x0bPmCartesian\x12\t\n\x01x\x18\n \x01(\x01\x12\t\n\x01y\x18\x14 \x01(\x01\x12\t\n\x01z\x18\x1e \x01(\x01:\x06\x92?\x03H\xac\x02\"{\n\x07\x45mcPose\x12&\n\x04tran\x18\n \x02(\x0b\x32\x18.machinetalk.PmCartesian\x12\t\n\x01\x61\x18\x14 \x01(\x01\x12\t\n\x01\x62\x18\x1e \x01(\x01\x12\t\n\x01\x63\x18( \x01(\x01\x12\t\n\x01u\x18\x32 \x01(\x01\x12\t\n\x01v\x18< \x01(\x01\x12\t\n\x01w\x18\x46 \x01(\x01:\x06\x92?\x03H\xad\x02')
  ,
  dependencies=[machinetalk_dot_protobuf_dot_nanopb__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)




_PMCARTESIAN = _descriptor.Descriptor(
  name='PmCartesian',
  full_name='machinetalk.PmCartesian',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='machinetalk.PmCartesian.x', index=0,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='y', full_name='machinetalk.PmCartesian.y', index=1,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='z', full_name='machinetalk.PmCartesian.z', index=2,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\254\002')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=141,
)


_EMCPOSE = _descriptor.Descriptor(
  name='EmcPose',
  full_name='machinetalk.EmcPose',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tran', full_name='machinetalk.EmcPose.tran', index=0,
      number=10, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='a', full_name='machinetalk.EmcPose.a', index=1,
      number=20, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='b', full_name='machinetalk.EmcPose.b', index=2,
      number=30, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='c', full_name='machinetalk.EmcPose.c', index=3,
      number=40, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='u', full_name='machinetalk.EmcPose.u', index=4,
      number=50, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='v', full_name='machinetalk.EmcPose.v', index=5,
      number=60, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='w', full_name='machinetalk.EmcPose.w', index=6,
      number=70, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\255\002')),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=266,
)

_EMCPOSE.fields_by_name['tran'].message_type = _PMCARTESIAN
DESCRIPTOR.message_types_by_name['PmCartesian'] = _PMCARTESIAN
DESCRIPTOR.message_types_by_name['EmcPose'] = _EMCPOSE

PmCartesian = _reflection.GeneratedProtocolMessageType('PmCartesian', (_message.Message,), dict(
  DESCRIPTOR = _PMCARTESIAN,
  __module__ = 'machinetalk.protobuf.emcclass_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.PmCartesian)
  ))
_sym_db.RegisterMessage(PmCartesian)

EmcPose = _reflection.GeneratedProtocolMessageType('EmcPose', (_message.Message,), dict(
  DESCRIPTOR = _EMCPOSE,
  __module__ = 'machinetalk.protobuf.emcclass_pb2'
  # @@protoc_insertion_point(class_scope:machinetalk.EmcPose)
  ))
_sym_db.RegisterMessage(EmcPose)


_PMCARTESIAN.has_options = True
_PMCARTESIAN._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\254\002'))
_EMCPOSE.has_options = True
_EMCPOSE._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('\222?\003H\255\002'))
# @@protoc_insertion_point(module_scope)
